<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//gl_ES

$LANG=array();


$LANG['backup'][0]="Copia de seguridade en SQL"; 
$LANG['backup'][1]="Copia de seguridade en XML"; 
$LANG['backup'][11]="Tamaño"; 
$LANG['backup'][13]="Ver/Descarga"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Delete this file"; 
$LANG['backup'][18]="Backup the database"; 
$LANG['backup'][19]="Agora"; 
$LANG['backup'][21]="O ficheiro xa existe"; 
$LANG['backup'][22]="Non se atopa o byte"; 
$LANG['backup'][23]="Erro MySQL empezando en"; 
$LANG['backup'][24]="Redirección automática. Si non é así, faga clic"; 

$LANG['bookmark'][1]="marcapáxinas"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Non ten marcadores gardados"; 
$LANG['bookmark'][4]="Novo marcador"; 
$LANG['bookmark'][5]="Marcadores Públicos"; 
$LANG['bookmark'][6]="Default view"; 

$LANG['buttons'][0]="Buscar"; 
$LANG['buttons'][2]="Aceptar"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Instalar"; 
$LANG['buttons'][5]="Desinstalar"; 
$LANG['buttons'][6]="Borrar"; 
$LANG['buttons'][7]="Actualizar"; 
$LANG['buttons'][8]="Gravar"; 
$LANG['buttons'][9]="Conectar"; 
$LANG['buttons'][10]="Desconectar"; 
$LANG['buttons'][11]="Seguinte"; 
$LANG['buttons'][12]="Anterior"; 
$LANG['buttons'][13]="Volver"; 
$LANG['buttons'][14]="Modificar"; 
$LANG['buttons'][15]="Calendario"; 
$LANG['buttons'][16]="Borrar"; 
$LANG['buttons'][17]="Invertir a selección"; 
$LANG['buttons'][18]="Marcar todo"; 
$LANG['buttons'][19]="Desmarcar todo"; 
$LANG['buttons'][20]="Mover"; 
$LANG['buttons'][21]="Restaurar"; 
$LANG['buttons'][22]="Purgar"; 
$LANG['buttons'][23]="Ver"; 
$LANG['buttons'][24]="Ascender"; 
$LANG['buttons'][25]="Descender"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Exportar"; 
$LANG['buttons'][32]="Fin"; 
$LANG['buttons'][33]="Principio"; 
$LANG['buttons'][34]="Cancelar"; 
$LANG['buttons'][37]="Importar"; 
$LANG['buttons'][38]="Desbloquear"; 
$LANG['buttons'][39]="Substituír"; 
$LANG['buttons'][40]="Ver todos"; 
$LANG['buttons'][41]="Activar"; 
$LANG['buttons'][42]="Desactivar"; 
$LANG['buttons'][43]="Examinar"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Antes"; 
$LANG['buttons'][47]="Despois"; 
$LANG['buttons'][48]="Transferir"; 
$LANG['buttons'][49]="Conservar"; 
$LANG['buttons'][50]="Probar"; 
$LANG['buttons'][51]="Gardar"; 
$LANG['buttons'][52]="Cargar"; 
$LANG['buttons'][53]="Limpar"; 
$LANG['buttons'][55]="Primeiro"; 
$LANG['buttons'][56]="Último"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="D"; 
$LANG['calendarD'][1]="L"; 
$LANG['calendarD'][2]="M"; 
$LANG['calendarD'][3]="M"; 
$LANG['calendarD'][4]="X"; 
$LANG['calendarD'][5]="V"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Domingo"; 
$LANG['calendarDay'][1]="Luns"; 
$LANG['calendarDay'][2]="Martes"; 
$LANG['calendarDay'][3]="Mércores"; 
$LANG['calendarDay'][4]="Xoves"; 
$LANG['calendarDay'][5]="Venres"; 
$LANG['calendarDay'][6]="Sábado"; 

$LANG['calendarM'][0]="Xaneiro"; 
$LANG['calendarM'][1]="Febreiro"; 
$LANG['calendarM'][2]="Marzo"; 
$LANG['calendarM'][3]="Abril"; 
$LANG['calendarM'][4]="Maio"; 
$LANG['calendarM'][5]="Xuño"; 
$LANG['calendarM'][6]="Xullo"; 
$LANG['calendarM'][7]="Agosto"; 
$LANG['calendarM'][8]="Setembro"; 
$LANG['calendarM'][9]="Outubro"; 
$LANG['calendarM'][10]="Novembro"; 
$LANG['calendarM'][11]="Decembro"; 

$LANG['cartridges'][0]="Cartucho"; 
$LANG['cartridges'][7]="Non se acharon cartuchos"; 
$LANG['cartridges'][9]="Non hai cartuchos"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Tipo de cartucho"; 
$LANG['cartridges'][13]="Novos"; 
$LANG['cartridges'][14]="Usados"; 
$LANG['cartridges'][15]="Usados"; 
$LANG['cartridges'][16]="Cartuchos"; 
$LANG['cartridges'][20]="Novo"; 
$LANG['cartridges'][21]="Usado"; 
$LANG['cartridges'][22]="Usado"; 
$LANG['cartridges'][24]="Agregado data"; 
$LANG['cartridges'][27]="Sobre"; 
$LANG['cartridges'][29]="Término de vida"; 
$LANG['cartridges'][32]="Modelos de impresoras compatibles"; 
$LANG['cartridges'][33]="Cartuchos usados"; 
$LANG['cartridges'][34]="Non hai cartuchos libres"; 
$LANG['cartridges'][35]="Cartuchos usados"; 
$LANG['cartridges'][37]="Cinta"; 
$LANG['cartridges'][39]="Contador de impresora"; 
$LANG['cartridges'][40]="Promedio en stock"; 
$LANG['cartridges'][41]="Utilización promedio"; 
$LANG['cartridges'][42]="Páxinas impresas promedio"; 

$LANG['central'][2]="Últimos"; 
$LANG['central'][4]="Sen eventos"; 
$LANG['central'][5]="Inicio"; 
$LANG['central'][6]="Desconexión"; 
$LANG['central'][7]="Axuda"; 
$LANG['central'][8]="Agregados"; 
$LANG['central'][9]="As súas incidencias en curso"; 
$LANG['central'][10]="Incidencias novas"; 
$LANG['central'][12]="Vista persoal"; 
$LANG['central'][13]="Vista global"; 
$LANG['central'][14]="Vista de Grupo"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Non"; 
$LANG['choice'][1]="Si"; 

$LANG['common'][0]="Sen nome"; 
$LANG['common'][1]="Material"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Fabricante"; 
$LANG['common'][6]="Nome do persoal"; 
$LANG['common'][7]="Elixa un persoal"; 
$LANG['common'][8]="Xestión de persoais..."; 
$LANG['common'][9]="Engadir un persoal..."; 
$LANG['common'][10]="Responsable técnico"; 
$LANG['common'][11]="Vista limitada"; 
$LANG['common'][12]="Configuración"; 
$LANG['common'][13]="Persoal"; 
$LANG['common'][14]="Persoais"; 
$LANG['common'][15]="Lugar"; 
$LANG['common'][16]="Nome"; 
$LANG['common'][17]="Tipo"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Número de serie"; 
$LANG['common'][20]="Número de inventario"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Modelo"; 
$LANG['common'][23]="Operación realizada con éxito"; 
$LANG['common'][24]="Non se escolleron elementos ou a operación está mal definida"; 
$LANG['common'][25]="Comentarios"; 
$LANG['common'][26]="Última modificación"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Borrado"; 
$LANG['common'][29]="Complementos"; 
$LANG['common'][30]="Novo item"; 
$LANG['common'][31]="Persoal baleiro"; 
$LANG['common'][32]="Características"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Usuario"; 
$LANG['common'][35]="Grupo"; 
$LANG['common'][36]="Categoría"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Replica o elemento tantas veces como conexións"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Alertas por email"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Nome"; 
$LANG['common'][44]="Default value(s)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="vCard"; 
$LANG['common'][47]="Progreso"; 
$LANG['common'][48]="Apelido"; 
$LANG['common'][49]="Ningún"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Nome completo"; 
$LANG['common'][52]="Servidor"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="O elemento non se atopa"; 
$LANG['common'][55]="Está seguro de que desexa borrar este elemento?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Título"; 
$LANG['common'][58]="Valor máximo"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Activo"; 
$LANG['common'][61]="Erro descoñecido"; 
$LANG['common'][62]="Outro"; 
$LANG['common'][63]="Erros"; 
$LANG['common'][64]="Supervisor"; 
$LANG['common'][65]="Interface"; 
$LANG['common'][66]="Todo"; 
$LANG['common'][67]="Outros"; 
$LANG['common'][68]="Apaisado"; 
$LANG['common'][69]="Retrato"; 
$LANG['common'][70]="Obxecto engadido satisfactoriamente"; 
$LANG['common'][71]="Obxecto actualizado satisfactoriamente"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Obxecto restaurado satisfactoriamente"; 
$LANG['common'][75]="Non ten permisos para facer de este item recurrente nesta entidade"; 
$LANG['common'][76]="Público"; 
$LANG['common'][77]="Privado"; 
$LANG['common'][78]="Configurar pública"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Durante a carga..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="A existencia de elementos ligados impiden a modificación deste atributo"; 
$LANG['common'][85]="Modificar a visibilidade nas subentidades"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nova tarxeta"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Porcentaxe libre"; 
$LANG['computers'][2]="Espazo libre"; 
$LANG['computers'][3]="Espazo global"; 
$LANG['computers'][4]="Sistema de ficheiros"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Engadir un volume"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Engadido"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Non hai monitor conectado"; 
$LANG['computers'][38]="Non hai impresoras conectadas"; 
$LANG['computers'][39]="Impresoras"; 
$LANG['computers'][40]="Monitores"; 
$LANG['computers'][46]="Periféricos"; 
$LANG['computers'][47]="Non hai periféricos conectados"; 
$LANG['computers'][48]="Modificación de lugar. Os elementos conectados foron desprazados ao mesmo lugar que o computador."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Modificación do usuario ou do grupo.Os elementos relacionados foron actualizados cos mesmos valores que o equipo."; 
$LANG['computers'][51]="Orixe de actualización"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Non hai teléfono conectado"; 
$LANG['computers'][55]="Teléfonos"; 
$LANG['computers'][56]="Modificación do estado. Os elementos relacionados actualizáronse co estado do computador."; 

$LANG['connect'][0]="Conexións directas"; 
$LANG['connect'][1]="Non conectado"; 
$LANG['connect'][15]="Actualización automática dos elementos seguintes"; 
$LANG['connect'][16]="Coidado! Os seguintes elementos dos dous computadores non coinciden"; 

$LANG['consumables'][0]="Consumibles"; 
$LANG['consumables'][1]="En stock"; 
$LANG['consumables'][2]="Referencia"; 
$LANG['consumables'][7]="Non se acharon consumibles"; 
$LANG['consumables'][9]="Ningún consumible"; 
$LANG['consumables'][12]="Tipo de consumible"; 
$LANG['consumables'][13]="Novos"; 
$LANG['consumables'][15]="Utilizados"; 
$LANG['consumables'][16]="Consumibles"; 
$LANG['consumables'][20]="Novo"; 
$LANG['consumables'][22]="Utilizados"; 
$LANG['consumables'][23]="Estado"; 
$LANG['consumables'][26]="Utilizado data"; 
$LANG['consumables'][32]="Dar"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Lugar de Almacenamiento"; 
$LANG['consumables'][37]="Reintegrar ao stock"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Engadir un novo compoñente"; 
$LANG['devices'][1]="Disco duro"; 
$LANG['devices'][2]="Tarxeta gráfica"; 
$LANG['devices'][3]="Tarxeta de rede"; 
$LANG['devices'][4]="Procesador"; 
$LANG['devices'][5]="Placa base"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Tarxeta de son"; 
$LANG['devices'][19]="Lectoras"; 
$LANG['devices'][20]="Controladoras"; 
$LANG['devices'][21]="Outros compoñentes"; 
$LANG['devices'][22]="Caixas"; 
$LANG['devices'][23]="Alimentación"; 
$LANG['devices'][24]="predeterminado"; 
$LANG['devices'][25]="Engadir un compoñente"; 
$LANG['devices'][26]="Borrado dun compoñente"; 

$LANG['device_case'][0]="formato"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Gravación"; 
$LANG['device_drive'][1]="Velocidade"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Capacidade"; 

$LANG['device_iface'][0]="Velocidade"; 
$LANG['device_iface'][2]="Enderezo MAC"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Potencia"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frecuencia"; 
$LANG['device_ram'][2]="Tamaño"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Ficheiro"; 
$LANG['document'][3]="Asunto"; 
$LANG['document'][4]="Tipo MIME"; 
$LANG['document'][7]="Tipo de documento"; 
$LANG['document'][9]="Extensión"; 
$LANG['document'][10]="Icono"; 
$LANG['document'][11]="Descarga autorizada"; 
$LANG['document'][15]="Descarga"; 
$LANG['document'][16]="Engadir un Documento"; 
$LANG['document'][18]="Documento"; 
$LANG['document'][19]="Elementos asociados"; 
$LANG['document'][21]="Documentos Asociados"; 
$LANG['document'][22]="Ficheiro actual"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Borrado correcto do ficheiro"; 
$LANG['document'][25]="Fallou o borrado do ficheiro"; 
$LANG['document'][26]="O ficheiro é válido, e foi descargado correctamente."; 
$LANG['document'][27]="Potencial ataque por upload ou ficheiro demasiado grande. Imposible mover o ficheiro temporal."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Fallou a creación do directorio"; 
$LANG['document'][30]="Comprobe que ten permisos"; 
$LANG['document'][31]="Directorio de almacenamento de documentos inexistente:"; 
$LANG['document'][32]="Tipo de ficheiro non autorizado"; 
$LANG['document'][33]="Ligazón web"; 
$LANG['document'][34]="Creación do directorio"; 
$LANG['document'][35]="Directorio de subida inexistente"; 
$LANG['document'][36]="Seleccionar un ficheiro instalado por FTP"; 
$LANG['document'][37]="Non hai ficheiros dispoñibles"; 
$LANG['document'][38]="Ficheiro non atopado"; 
$LANG['document'][39]="Documento movido correctamente"; 
$LANG['document'][40]="Problema ao mover o ficheiro"; 
$LANG['document'][41]="Documento copiado correctamente"; 
$LANG['document'][42]="Engadido por"; 
$LANG['document'][43]="Ficheiro descoñecido"; 
$LANG['document'][44]="Nome de ficheiro incorrecto"; 
$LANG['document'][45]="Non ten permisos para acceder a este ficheiro"; 
$LANG['document'][46]="Fallo no envío do ficheiro (sen dúbida demasiado grande)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Entidade"; 
$LANG['entity'][2]="Entidade Raíz"; 
$LANG['entity'][3]="Asociar a unha entidade"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Asignación automática de usuarios"; 
$LANG['entity'][7]="estrutura en árbore"; 
$LANG['entity'][8]="Por entidade"; 
$LANG['entity'][9]="Entidades fillas"; 
$LANG['entity'][10]="Escoller a entidade desexada"; 
$LANG['entity'][11]="para ver a entidade e as súas sub-entidades"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Incidencia"; 
$LANG['event'][3]="Nivel"; 
$LANG['event'][4]="Mensaxe"; 
$LANG['event'][18]="Campo"; 
$LANG['event'][19]="Modificación"; 
$LANG['event'][20]="Non hai histórico"; 

$LANG['financial'][1]="Contrato"; 
$LANG['financial'][2]="Ten vida"; 
$LANG['financial'][3]="Datos financeiros"; 
$LANG['financial'][4]="Número"; 
$LANG['financial'][5]="Costo"; 
$LANG['financial'][6]="Tipo de contrato"; 
$LANG['financial'][8]="Duración"; 
$LANG['financial'][9]="anos"; 
$LANG['financial'][10]="Preaviso"; 
$LANG['financial'][11]="Periodicidade de facturación"; 
$LANG['financial'][13]="Número contable"; 
$LANG['financial'][14]="Data de compra"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Datos de garantía"; 
$LANG['financial'][18]="Número de pedido"; 
$LANG['financial'][19]="Remito de entrega"; 
$LANG['financial'][20]="Número de inhibición"; 
$LANG['financial'][21]="Prezo de compra"; 
$LANG['financial'][22]="Tipo de amortización"; 
$LANG['financial'][23]="Duración de amortización"; 
$LANG['financial'][24]="Engadir Contacto..."; 
$LANG['financial'][25]="Engadir Provedor..."; 
$LANG['financial'][26]="Provedor"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Engadir un Contacto"; 
$LANG['financial'][36]="Engadir un Contrato"; 
$LANG['financial'][42]="Comercial"; 
$LANG['financial'][43]="Técnico"; 
$LANG['financial'][44]="Dirección"; 
$LANG['financial'][45]="Sitio Web"; 
$LANG['financial'][46]="Contactos asociados"; 
$LANG['financial'][47]="Lineal"; 
$LANG['financial'][48]="Reducido"; 
$LANG['financial'][50]="Préstamo"; 
$LANG['financial'][51]="Locación"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Seguros"; 
$LANG['financial'][54]="Mantemento Hardware"; 
$LANG['financial'][55]="Mantemento Software"; 
$LANG['financial'][56]="Prestación"; 
$LANG['financial'][57]="mes"; 
$LANG['financial'][59]="Horas de servizo"; 
$LANG['financial'][60]="de semana"; 
$LANG['financial'][61]="sábado"; 
$LANG['financial'][62]="domingo e feirados"; 
$LANG['financial'][65]="Provedores asociados"; 
$LANG['financial'][66]="Contratos asociados"; 
$LANG['financial'][68]="Activar os datos financeiros"; 
$LANG['financial'][69]="Periodicidade do contrato"; 
$LANG['financial'][76]="Data de posta en servizo"; 
$LANG['financial'][77]="Coeficiente de amortización"; 
$LANG['financial'][78]="Prezo extensión garantía"; 
$LANG['financial'][79]="Tipo de Terceiro"; 
$LANG['financial'][80]="Expiración de garantía"; 
$LANG['financial'][81]="Valor Neto Contable (VNC)"; 
$LANG['financial'][82]="Número de factura"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Para este tipo de elemento, os datos financeiros non son máis que un modelo para os elementos que vostede engadirá a continuación."; 
$LANG['financial'][85]="Non se achou o elemento solicitado"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Orzamento"; 
$LANG['financial'][88]="Expira o:"; 
$LANG['financial'][89]="CTP (prezo de compra + custo de incidencias)"; 
$LANG['financial'][90]="CTP mensual"; 
$LANG['financial'][91]="CTP"; 
$LANG['financial'][92]="VNC"; 
$LANG['financial'][93]="Contratos expirados fai menos de 30 días"; 
$LANG['financial'][94]="Contratos que expiran en menos de 7 días"; 
$LANG['financial'][95]="Contratos que expiran en menos de 30 días"; 
$LANG['financial'][96]="Contratos cuxo preaviso comeza en menos de 7 días"; 
$LANG['financial'][97]="Contratos cuxo preaviso comeza en menos de 30 días"; 
$LANG['financial'][98]="Expiración"; 
$LANG['financial'][99]="Expiración+preaviso"; 
$LANG['financial'][100]="Código postal"; 
$LANG['financial'][101]="Cidade"; 
$LANG['financial'][102]="Estado"; 
$LANG['financial'][103]="País"; 
$LANG['financial'][104]="Material conectado"; 
$LANG['financial'][105]="Tácito"; 
$LANG['financial'][106]="Expresa"; 
$LANG['financial'][107]="Renovación"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="horas"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Moi urxente"; 
$LANG['help'][4]="Urxente"; 
$LANG['help'][5]="Mediana"; 
$LANG['help'][6]="Baixa"; 
$LANG['help'][7]="Moi baixa"; 
$LANG['help'][8]="Infórmenme do seguimento"; 
$LANG['help'][11]="A miña dirección de email"; 
$LANG['help'][14]="Enviar mensaxe"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="A súa solicitude foi enviada, tratamento en curso."; 
$LANG['help'][19]="Grazas por utilizar o noso sistema de axuda automática."; 
$LANG['help'][22]="Buscar o seu número de computador"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Tipo de material"; 
$LANG['help'][25]="computador"; 
$LANG['help'][26]="Electrónica de rede"; 
$LANG['help'][27]="Impresora"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Periférico"; 
$LANG['help'][30]="Xeral"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Teléfonos"; 
$LANG['help'][40]="Incidencia sen título, porfavor introdúzao."; 
$LANG['help'][41]="Ningunha categoría no seu ticket, por favor, volva a intentalo."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Instalación ou actualización de GLPI"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Instalación"; 
$LANG['install'][4]="Actualización"; 
$LANG['install'][5]="Verificación da compatibilidade da súa contorna coa execución de GLPI"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Resultados"; 
$LANG['install'][8]="Proba do intérprete PHP"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI non é compatible coa diretiva zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP version is at least 5.x - Perfect !"; 
$LANG['install'][12]="Proba de Sesións"; 
$LANG['install'][13]="O seu intérprete PHP non foi compilado con soporte de sesións!"; 
$LANG['install'][14]="O soporte de sesións está operativo - Perfecto!"; 
$LANG['install'][15]="Comprobe que estea activado o soporte de sesións no seu php.ini"; 
$LANG['install'][16]="Probas de escritura de ficheiros dump"; 
$LANG['install'][17]="Non crear o ficheiro."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="O ficheiro foi creado pero non se puido borrar."; 
$LANG['install'][20]="Un ficheiro e un directorio foron creados e borrados - Perfecto!"; 
$LANG['install'][21]="Proba de escritura de ficheiros de documentos"; 
$LANG['install'][22]="Creouse un ficheiro - Perfecto!"; 
$LANG['install'][23]="Proba de escritura do ficheiro de configuración"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Continuar?"; 
$LANG['install'][26]="Continuar"; 
$LANG['install'][27]="Reintentar"; 
$LANG['install'][28]="Configuración da conexión á base de datos"; 
$LANG['install'][29]="Parámetros de conexión á base de datos"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Proba da conexión á base de datos"; 
$LANG['install'][35]="Imposible conectarse á base de datos"; 
$LANG['install'][36]="O servidor respondeu"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Seleccione unha base de datos:"; 
$LANG['install'][39]="Crear unha nova base de datos ou utilizar a que xa existe:"; 
$LANG['install'][40]="Seleccione a base de datos a actualizar:"; 
$LANG['install'][41]="Imposible utilizar a base:"; 
$LANG['install'][43]="OK - A base foi inicializada"; 
$LANG['install'][47]="Imposible escribir o ficheiro de configuración da súa base de datos"; 
$LANG['install'][48]="Erro na creación da base!"; 
$LANG['install'][49]="Non seleccionou a base de datos!"; 
$LANG['install'][50]="Proba de escritura de ficheiros de sesións"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Proba de escritura dos ficheiros de log"; 
$LANG['install'][55]="A instalación rematou"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="glpi/glpi para a conta administrador"; 
$LANG['install'][59]="tech/tech para a conta de técnico"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Utilizar GLPI"; 
$LANG['install'][65]="Proba da extensión magic_quotes_sybase"; 
$LANG['install'][66]="GLPI non pode funcionar coa opción magic_quotes_sybase. Por favor desactive esta opción e reintente"; 
$LANG['install'][67]="O seu servidor non utiliza a opción magic_quotes_sybase - Perfecto!"; 
$LANG['install'][68]="Proba sesión de autoinicio"; 
$LANG['install'][69]="session.auto_start está activada. Revisar o ficheiro .htaccess no raíz de GLPI para máis información"; 
$LANG['install'][70]="Imposible crear o ficheiro de conexión á base de datos, comprobe os permisos sobre os ficheiros"; 
$LANG['install'][71]="Proba da extensión mysql."; 
$LANG['install'][72]="Debe compilar o seu PHP coa extensión Mysql."; 
$LANG['install'][73]="OK - a función mysql_query() existe - Perfecto!"; 
$LANG['install'][74]="Proba de utilización de Session_use_trans_sid"; 
$LANG['install'][75]="Debe desactivar a opción Session_use_trans_id no seu PHP.ini"; 
$LANG['install'][76]="OK - As sesións funcionan (non hai problemas de trans_id) - Perfecto!"; 
$LANG['install'][77]="Etapa"; 
$LANG['install'][81]="Inicio da instalación"; 
$LANG['install'][82]="Base de datos creada"; 
$LANG['install'][85]="Atopáronse as funcións - Perfecto!"; 
$LANG['install'][86]="Comprobar a memoria asignada"; 
$LANG['install'][87]="Memoria asignada:"; 
$LANG['install'][88]="A minimum of 64MB is commonly required for GLPI."; 
$LANG['install'][89]="Perfecto!"; 
$LANG['install'][90]="Intente aumentar o parámetro memory_limit no ficheiro php.ini."; 
$LANG['install'][91]="Allocated memory > 64M"; 
$LANG['install'][92]="Licenza"; 
$LANG['install'][93]="Lin e ACEPTO os termos da licenza enunciados enriba."; 
$LANG['install'][94]="Lin e NON ACEPTO os termos da licenza enunciados enriba"; 
$LANG['install'][95]="Memoria non limitada"; 
$LANG['install'][96]="Memoria ilimitada"; 
$LANG['install'][97]="Check permissions to the directory:"; 
$LANG['install'][99]="Proba de escritura dos ficheiros de caché"; 
$LANG['install'][100]="Non se puido crear o directorio."; 
$LANG['install'][101]="Creouse o directorio pero non se puido borrar."; 
$LANG['install'][102]="Proba das funcions  json"; 
$LANG['install'][103]="GLPI non pode funcionar correctamente sen as funcións json_encode e json_decode"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="por"; 
$LANG['job'][4]="Solicitante"; 
$LANG['job'][5]="Asignada a"; 
$LANG['job'][6]="Técnico"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Describe the Problem/Action"; 
$LANG['job'][12]="Non hai seguimento para esta incidencia."; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Seguimento por email"; 
$LANG['job'][20]="Duración total"; 
$LANG['job'][21]="Horas"; 
$LANG['job'][22]="Minutos"; 
$LANG['job'][29]="Engadir un novo seguimento"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Duración"; 
$LANG['job'][32]="Ningunha"; 
$LANG['job'][33]="Descrición baleira"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planificación"; 
$LANG['job'][37]="Seguimento"; 
$LANG['job'][38]="Incidencia"; 
$LANG['job'][39]="Modificar un seguimento"; 
$LANG['job'][40]="Custo horario"; 
$LANG['job'][41]="Custo fixo"; 
$LANG['job'][42]="Custo do material"; 
$LANG['job'][43]="Custo total"; 
$LANG['job'][44]="Orixe da solicitude"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Estado"; 
$LANG['joblist'][1]="Só os meus"; 
$LANG['joblist'][2]="Prioridade"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Asignada a"; 
$LANG['joblist'][6]="Descrición"; 
$LANG['joblist'][7]="Nova incidencia para este item..."; 
$LANG['joblist'][8]="Non se atoparon incidencias."; 
$LANG['joblist'][9]="Nova"; 
$LANG['joblist'][10]="Pechada (resolta)"; 
$LANG['joblist'][11]="Aberta o"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="Pechada (non resolta)"; 
$LANG['joblist'][18]="En curso (asignada)"; 
$LANG['joblist'][19]="En curso (planificada)"; 
$LANG['joblist'][21]="En curso"; 
$LANG['joblist'][26]="En espera"; 
$LANG['joblist'][27]="Email para o seguimento"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="Preguntas Frecuentes"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Seleccionar unha categoría para este artigo:"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Modificar este artigo"; 
$LANG['knowbase'][9]="Borrar este artigo"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Raíz"; 
$LANG['knowbase'][13]="Nome da categoría"; 
$LANG['knowbase'][14]="Tema"; 
$LANG['knowbase'][15]="Contido"; 
$LANG['knowbase'][24]="Acceder ás Preguntas Frecuentes"; 
$LANG['knowbase'][26]="Vistas"; 
$LANG['knowbase'][27]="O"; 
$LANG['knowbase'][29]="Artigos recentes"; 
$LANG['knowbase'][30]="Artigos máis consultados"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Sincronización dos usuarios xa importados"; 
$LANG['ldap'][2]="Importación de usuarios novos"; 
$LANG['ldap'][3]="Non hai usuarios que importar"; 
$LANG['ldap'][4]="Elección do servidor LDAP"; 
$LANG['ldap'][5]="Elixa o servidor LDAP do que se importarán os usuarios"; 
$LANG['ldap'][6]="Imposible conectar co servidor LDAP"; 
$LANG['ldap'][7]="Non hai ningún servidor LDAP definido en GLPI"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Proba de conexión co servidor LDAP"; 
$LANG['ldap'][12]="Sincronización"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="en GLPI"; 
$LANG['ldap'][15]="Sincronizar"; 
$LANG['ldap'][16]="Configuración previa"; 
$LANG['ldap'][17]="Directorio Activo"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Replicar"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Servidor principal"; 
$LANG['ldap'][22]="Réplica(s)"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Importación de novos grupos"; 
$LANG['ldap'][25]="Ningún grupo para ser importado"; 
$LANG['ldap'][30]="Cómo deben manipularse os alias do LDAP"; 
$LANG['ldap'][31]="Nunca (predeterminado)"; 
$LANG['ldap'][32]="Sempre desferenciado"; 
$LANG['ldap'][33]="Desreferenciado durante a procura (non durante a localización)"; 
$LANG['ldap'][34]="Desreferenciado cando se fai a localización (non durante a procura)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Ligazón ou nome de ficheiro"; 
$LANG['links'][4]="Tipo de materiais asociados"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Non hai ligazóns definidas"; 
$LANG['links'][9]="Contido do ficheiro"; 

$LANG['log'][1]="sistema"; 
$LANG['log'][16]="planificación"; 
$LANG['log'][18]="compoñentes"; 
$LANG['log'][20]="engadir o elemento"; 
$LANG['log'][21]="actualización do elemento"; 
$LANG['log'][22]="borrado do elemento"; 
$LANG['log'][23]="reposición do elemento"; 
$LANG['log'][24]="purga do elemento"; 
$LANG['log'][26]="desconexión do elemento"; 
$LANG['log'][27]="conexión do elemento"; 
$LANG['log'][28]="modificación de compoñentes"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="Asociación dun tipo"; 
$LANG['log'][31]="borrado dun tipo"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="borrado de ligazón cun elemento"; 
$LANG['log'][34]="Engadir ligazón con provedor"; 
$LANG['log'][35]="borrado de ligazón con provedor"; 
$LANG['log'][40]="Conexión IP"; 
$LANG['log'][41]="fallo de conexión"; 
$LANG['log'][42]="Reserva"; 
$LANG['log'][44]="Titulado"; 
$LANG['log'][45]="Correcta"; 
$LANG['log'][46]="Errada"; 
$LANG['log'][48]="engadir usuario ao grupo"; 
$LANG['log'][49]="borrado de usuario no grupo"; 
$LANG['log'][55]="Conexión"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="engadido un usuario á entidade"; 
$LANG['log'][62]="borrado dun usuario da entidade"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="regra"; 
$LANG['log'][66]="Seguridade"; 
$LANG['log'][67]="cambio de notas"; 
$LANG['log'][70]="Engadido un porto de rede"; 
$LANG['log'][71]="Engadidos varios portos de rede"; 
$LANG['log'][73]="eliminación dun porto de rede"; 
$LANG['log'][74]="eliminación de varios portos de rede"; 
$LANG['log'][75]="o porto de rede moveuse"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="engadindo versión"; 
$LANG['log'][83]="modificación da versión"; 
$LANG['log'][84]="eliminación da versión"; 
$LANG['log'][85]="engadindo licenza"; 
$LANG['log'][86]="modificación da licenza"; 
$LANG['log'][87]="eliminación da licenza"; 
$LANG['log'][88]="engadindo cartuchos"; 
$LANG['log'][89]="engadindo consumibles"; 
$LANG['log'][90]="exclusión dun cartucho"; 
$LANG['log'][91]="exclusión dun consumible"; 
$LANG['log'][92]="restauración dun cartucho"; 
$LANG['log'][93]="restauración dun consumible"; 
$LANG['log'][94]="actualización de cartuchos"; 
$LANG['log'][95]="instalación de cartuchos"; 
$LANG['log'][96]="desinstalación de cartuchos"; 
$LANG['log'][97]="liberación dun consumible polo usuario"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Última conexión"; 
$LANG['login'][1]="Volver"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Acceso denegado"; 
$LANG['login'][6]="Usuario"; 
$LANG['login'][7]="Contrasinal"; 
$LANG['login'][8]="Usuario ou contrasinal baleiros"; 
$LANG['login'][9]="Aínda non"; 
$LANG['login'][10]="Identificación"; 
$LANG['login'][11]="Usuario non autorizado a conectarse"; 
$LANG['login'][12]="Usuario ou contrasinal erróneos"; 
$LANG['login'][13]="Contrasinal baleira"; 
$LANG['login'][14]="Usuario descoñecido"; 
$LANG['login'][15]="Usuario non atopado ou atopados varios usuarios"; 
$LANG['login'][16]="Fallo na identificación LDAP"; 
$LANG['login'][18]="Base interna de GLPI"; 
$LANG['login'][20]="Non ten acceso a esta aplicación. A súa conta foi desactivada ou borrada."; 
$LANG['login'][21]="Proba de conexión co servidor IMAP/POP"; 
$LANG['login'][22]="Proba correcta"; 
$LANG['login'][23]="Proba errada"; 
$LANG['login'][24]="Data da última actualización"; 
$LANG['login'][25]="Non ten permisos para conectarse a esta aplicación"; 
$LANG['login'][26]="Debe activar Javascript no seu navegador"; 
$LANG['login'][27]="Debe aceptar cookies para acceder á aplicación"; 
$LANG['login'][30]="Cambiar o método de identificación"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Identificación sobre a base de datos de GLPI"; 
$LANG['login'][33]="Identificación sobre o servidor POP/IMAP"; 

$LANG['mailgate'][0]="Mail Receiver"; 
$LANG['mailgate'][2]="Recuperar agora"; 
$LANG['mailgate'][3]="Número de mensaxes dispoñibles e recuperados"; 
$LANG['mailgate'][4]="A extensión mbstring non está dispoñible. Teña coidado cos xogos de carácteres que utiliza."; 
$LANG['mailgate'][5]="Ficheiro adxunto inválido"; 
$LANG['mailgate'][6]="Ficheiro adxunto demasiado grande"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Descrición da incidencia"; 
$LANG['mailing'][10]="Novo seguimento para esta incidencia"; 
$LANG['mailing'][12]="Asignación de incidencia"; 
$LANG['mailing'][14]="Modificación da categoría da incidencia"; 
$LANG['mailing'][15]="Modificación da prioridade da incidencia"; 
$LANG['mailing'][17]="Modificación do material involucrado na incidencia"; 
$LANG['mailing'][18]="Modificación do autor da incidencia"; 
$LANG['mailing'][19]="Nova reserva"; 
$LANG['mailing'][20]="Modificación do grupo da incidencia"; 
$LANG['mailing'][21]="Modificación da orixe da incidencia"; 
$LANG['mailing'][23]="Modificación de reserva"; 
$LANG['mailing'][26]="Documento engadido :"; 
$LANG['mailing'][27]="Modificación do estado da incidencia"; 
$LANG['mailing'][29]="Anular a reserva"; 
$LANG['mailing'][30]="Modificación de incidencia"; 
$LANG['mailing'][31]="Esta é a mensaxe de proba de envío de email"; 
$LANG['mailing'][32]="Proba de mail"; 
$LANG['mailing'][33]="Alerta de cartuchos"; 
$LANG['mailing'][35]="Limiar de alerta alcanzado para o tipo de consumibles:"; 
$LANG['mailing'][36]="Alerta de consumibles"; 
$LANG['mailing'][37]="Contrato en período de preaviso:"; 
$LANG['mailing'][39]="Alerta de contratos"; 
$LANG['mailing'][40]="Material chegado a caducidade de garantía:"; 
$LANG['mailing'][41]="Alerta de datos financeiros"; 
$LANG['mailing'][42]="Modificación do custo por hora"; 
$LANG['mailing'][43]="Modificación do custo fixo"; 
$LANG['mailing'][44]="Modificación do custo do material"; 
$LANG['mailing'][45]="Modificación do título da incidencia"; 
$LANG['mailing'][46]="Modificación da descrición da incidencia"; 
$LANG['mailing'][47]="Erro no envío do email"; 
$LANG['mailing'][48]="Cambio na data de apertura"; 
$LANG['mailing'][49]="Cambio en data cerrada"; 
$LANG['mailing'][50]="Cambiar receptor do recibo"; 
$LANG['mailing'][51]="Licenza expirada :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Non hai categoría asignada"; 
$LANG['mailing'][101]="Seguimento por email activado"; 
$LANG['mailing'][102]="Seguimento por email desactivado"; 
$LANG['mailing'][104]="Duración da incidencia"; 
$LANG['mailing'][105]="Non asignada"; 
$LANG['mailing'][107]="Non hai material involucrado"; 
$LANG['mailing'][109]="Sen grupo"; 
$LANG['mailing'][110]="Email non válido"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="computadores"; 
$LANG['Menu'][1]="Electrónica de rede"; 
$LANG['Menu'][2]="Impresoras"; 
$LANG['Menu'][3]="Monitores"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Informes"; 
$LANG['Menu'][11]="Preferenzas"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Estatísticas"; 
$LANG['Menu'][14]="Usuarios"; 
$LANG['Menu'][15]="Administración"; 
$LANG['Menu'][16]="Periféricos"; 
$LANG['Menu'][17]="Reservas"; 
$LANG['Menu'][18]="Utilidades"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="Preguntas Frecuentes"; 
$LANG['Menu'][21]="Cartuchos"; 
$LANG['Menu'][22]="Contactos"; 
$LANG['Menu'][23]="Provedores"; 
$LANG['Menu'][24]="Datos financeiros"; 
$LANG['Menu'][25]="Contratos"; 
$LANG['Menu'][26]="Xestión"; 
$LANG['Menu'][27]="Documentos"; 
$LANG['Menu'][28]="Estados"; 
$LANG['Menu'][29]="Planificación"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Consumibles"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Teléfonos"; 
$LANG['Menu'][35]="Perfís"; 
$LANG['Menu'][36]="Grupos"; 
$LANG['Menu'][37]="Entidades"; 
$LANG['Menu'][38]="Inventario"; 
$LANG['Menu'][39]="Receivers"; 
$LANG['Menu'][40]="Marcapáxinas"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Micrófono"; 
$LANG['monitors'][15]="Altofalantes"; 
$LANG['monitors'][18]="Opcións"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Tamaño"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivote"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Portos de rede"; 
$LANG['networking'][13]="portos de rede atopados"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Conectado a"; 
$LANG['networking'][19]="Engadir un porto..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="sobre"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="O porto"; 
$LANG['networking'][46]="Engadir varios portos..."; 
$LANG['networking'][47]="De"; 
$LANG['networking'][48]="A"; 
$LANG['networking'][51]="Roseta"; 
$LANG['networking'][55]="Asociar unha VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Elixa unha dirección MAC na lista ou especifíquea aquí debaixo."; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Pasarela"; 
$LANG['networking'][60]="Máscara"; 
$LANG['networking'][61]="Subrede"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Opcións de importación"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Excluir as seguintes etiquetas (separador $, nada para todas)"; 
$LANG['ocsconfig'][10]="Importación global"; 
$LANG['ocsconfig'][11]="Non importar"; 
$LANG['ocsconfig'][12]="Importación única"; 
$LANG['ocsconfig'][13]="Importación única: impórtase todo tal cal"; 
$LANG['ocsconfig'][14]="Importación global: impórtase todo pero o material xestiónase de xeito global (sen duplicados)"; 
$LANG['ocsconfig'][15]="Non importar: GLPI non importará estes elementos"; 
$LANG['ocsconfig'][16]="Estado predeterminado"; 
$LANG['ocsconfig'][17]="Limitar a importación ás tags seguintes (separador $; nada, para todos)"; 
$LANG['ocsconfig'][18]="Asegúrese de ter xestionado correctamente os duplicados en OCSNG"; 
$LANG['ocsconfig'][19]="Dependencia de importación sobre o número de serie"; 
$LANG['ocsconfig'][27]="Información xeral"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Portos"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Rexistro de Windows"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Comportamento durante a desconexión"; 
$LANG['ocsconfig'][49]="Papelera"; 
$LANG['ocsconfig'][50]="Eliminación"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="baleiro"; 
$LANG['ocsconfig'][57]="igual"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="Inventario OCS NG"; 
$LANG['ocsng'][1]="Sincronización de computadores xa importados"; 
$LANG['ocsng'][2]="Importación de computadores novos"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Ligar computadores novos a computadores existentes"; 
$LANG['ocsng'][5]="Importar computadores novos"; 
$LANG['ocsng'][6]="Actualización automática"; 
$LANG['ocsng'][7]="Importado desde OCSNG"; 
$LANG['ocsng'][8]="Importación correcta"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Actualización de computadores"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Data de importación a GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Non hai campos bloqueados"; 
$LANG['ocsng'][16]="Campos bloqueados"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Coidado! Os datos importados (vexa a súa configuración) substituirán aos existentes"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Forzar a sincronización"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Monitores bloqueados"; 
$LANG['ocsng'][32]="Periféricos bloqueados"; 
$LANG['ocsng'][34]="Impresoras bloqueadas"; 
$LANG['ocsng'][36]="Entidade de destino"; 
$LANG['ocsng'][37]="Activar a vista preliminar"; 
$LANG['ocsng'][38]="Desactivar a vista preliminar"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Modo de importación manual"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="ID OCS"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Axente"; 
$LANG['ocsng'][50]="IPs bloqueadas"; 
$LANG['ocsng'][52]="Software bloqueado"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volume(s) bloqueado(s)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="ata"; 
$LANG['pager'][2]="desde"; 
$LANG['pager'][3]="de"; 
$LANG['pager'][4]="Mostrar"; 
$LANG['pager'][5]="elementos"; 

$LANG['peripherals'][18]="Marca"; 
$LANG['peripherals'][31]="Xestión global"; 
$LANG['peripherals'][32]="Xestión individual"; 
$LANG['peripherals'][33]="Tipo de xestión"; 

$LANG['phones'][18]="Marca"; 
$LANG['phones'][36]="Alimentación"; 
$LANG['phones'][38]="Casco"; 
$LANG['phones'][39]="Altofalante"; 
$LANG['phones'][40]="Cantidade de liñas"; 

$LANG['planning'][0]="O técnico solicitado xa ten un servizo previsto para este horario."; 
$LANG['planning'][1]="Erro nas datas. A data inicial é posterior á data final"; 
$LANG['planning'][5]="Día"; 
$LANG['planning'][6]="Semana"; 
$LANG['planning'][8]="Servizo"; 
$LANG['planning'][9]="Por"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="Sincronización Webcal://"; 
$LANG['planning'][14]="Mes"; 
$LANG['planning'][15]="A súa planificación"; 
$LANG['planning'][16]="Información"; 
$LANG['planning'][17]="Pendente"; 
$LANG['planning'][18]="Terminado"; 

$LANG['plugins'][0]="Lista de Plugins"; 
$LANG['plugins'][2]="Instalado / non configurado"; 
$LANG['plugins'][3]="Instalado / non activado"; 
$LANG['plugins'][4]="Erro / ao limpiar"; 
$LANG['plugins'][5]="Función(s) inexistente(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serie"; 
$LANG['printers'][15]="Paralelo"; 
$LANG['printers'][18]="Portos"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Contador de páxina inicial"; 
$LANG['printers'][31]="Páxinas impresas"; 

$LANG['profiles'][0]="Permiso global"; 
$LANG['profiles'][1]="Permiso local"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Abrir unha incidencia"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Ver todas as incidencias"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Lectura"; 
$LANG['profiles'][11]="Escritura"; 
$LANG['profiles'][12]="Sen acceso"; 
$LANG['profiles'][13]="Perfil predeterminado"; 
$LANG['profiles'][14]="Borrar unha incidencia"; 
$LANG['profiles'][15]="Engadir un seguimento a todas as incidencias"; 
$LANG['profiles'][16]="Estar a cargo dunha incidencia"; 
$LANG['profiles'][17]="Quitar unha incidencia"; 
$LANG['profiles'][18]="Modificar unha incidencia"; 
$LANG['profiles'][19]="Asignar unha incidencia"; 
$LANG['profiles'][20]="Ver planificación persoal"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Perfil"; 
$LANG['profiles'][23]="Administración de reservas"; 
$LANG['profiles'][24]="Cambiar o contrasinal"; 
$LANG['profiles'][26]="Ver as incidencias creadas por grupo asociado"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Recursivo"; 
$LANG['profiles'][29]="Dinámico"; 
$LANG['profiles'][30]="Ver a información OCSNG"; 
$LANG['profiles'][31]="Sincronización manual con OCSNG"; 
$LANG['profiles'][32]="Ver as incidencias asignadas (persoal + grupo asociado)"; 
$LANG['profiles'][33]="Non se atoparon usuarios"; 
$LANG['profiles'][34]="Lenda"; 
$LANG['profiles'][35]="Modificar todos os seguimentos"; 
$LANG['profiles'][36]="Ver a planificación das persoas dos meus grupos"; 
$LANG['profiles'][37]="Entidade predeterminada"; 
$LANG['profiles'][38]="Visibilidade"; 
$LANG['profiles'][39]="Asignación"; 
$LANG['profiles'][40]="Actualizar"; 
$LANG['profiles'][41]="Creación"; 
$LANG['profiles'][42]="Asociación"; 
$LANG['profiles'][43]="Método de autenticación e sincronización dos usuarios"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Sección"; 
$LANG['registry'][2]="Ruta"; 
$LANG['registry'][3]="Clave/valor"; 
$LANG['registry'][4]="Claves de rexistro atopadas"; 
$LANG['registry'][5]="Non se atoparon ningunha clave do Rexistro de Windows"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Notas persoais"; 
$LANG['reminder'][1]="Notas públicas"; 
$LANG['reminder'][6]="Nova nota"; 
$LANG['reminder'][9]="Texto"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Sen título"; 
$LANG['reminder'][16]="Notas globais"; 

$LANG['reports'][0]="Seleccionar un informe"; 
$LANG['reports'][4]="Lista do material baixo contrato"; 
$LANG['reports'][11]="Material baixo contrato"; 
$LANG['reports'][12]="Tipo de material"; 
$LANG['reports'][13]="Datas"; 
$LANG['reports'][15]="Mostrar informe"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Informe predeterminado"; 
$LANG['reports'][27]="Por contratos"; 
$LANG['reports'][28]="Por anos"; 
$LANG['reports'][33]="Informe de rede"; 
$LANG['reports'][36]="Dispositivos conectados"; 
$LANG['reports'][37]="Rosetas"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Por lugar"; 
$LANG['reports'][41]="By hardware"; 
$LANG['reports'][42]="Por roseta"; 
$LANG['reports'][46]="hardware ports"; 
$LANG['reports'][47]="Porto do dispositivo"; 
$LANG['reports'][49]="Network report by hardware"; 
$LANG['reports'][51]="Informe de rede por roseta"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Informe de rede por lugar"; 
$LANG['reports'][57]="Lista de materiais"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Data de apertura"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="Outros datos financeiros (licenzas, consumibles, cartuchos)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Material reservable"; 
$LANG['reservation'][2]="Material non dispoñible temporalmente"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Reservar"; 
$LANG['reservation'][9]="Reservar un material"; 
$LANG['reservation'][16]="Ata"; 
$LANG['reservation'][17]="Desde"; 
$LANG['reservation'][18]="O material solicitado xa está reservado para este horario."; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modificar o comentario"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="Por semana"; 
$LANG['reservation'][29]="Por día"; 
$LANG['reservation'][30]="veces"; 
$LANG['reservation'][31]="Por"; 
$LANG['reservation'][35]="Reservas en curso e futuras"; 
$LANG['reservation'][36]="Reservas pasadas"; 
$LANG['reservation'][37]="Non hai reservas"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Isto borrará todas as reservas en curso."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="é"; 
$LANG['rulesengine'][1]="non é"; 
$LANG['rulesengine'][2]="contén"; 
$LANG['rulesengine'][3]="non contén"; 
$LANG['rulesengine'][4]="comeza por"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Criterios"; 
$LANG['rulesengine'][7]="Accións"; 
$LANG['rulesengine'][8]="Xestión de regras"; 
$LANG['rulesengine'][9]="Logical operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Tipo de acción"; 
$LANG['rulesengine'][12]="Campos"; 
$LANG['rulesengine'][13]="Valor"; 
$LANG['rulesengine'][14]="Condición"; 
$LANG['rulesengine'][15]="Motivo"; 
$LANG['rulesengine'][16]="Criterio"; 
$LANG['rulesengine'][17]="Regras"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Regras de asignación de entidade e de permisos"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Asignar"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Elección do tipo de regra"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Lista de regras"; 
$LANG['rulesengine'][30]="Acción"; 
$LANG['rulesengine'][33]="Dicionario dos títulos"; 
$LANG['rulesengine'][35]="dicionario de software"; 
$LANG['rulesengine'][36]="Dicionario de fabricantes"; 
$LANG['rulesengine'][37]="Regras de asignación de categoría aos programas"; 
$LANG['rulesengine'][38]="Recalcular"; 
$LANG['rulesengine'][40]="a categoría"; 
$LANG['rulesengine'][41]="Validación"; 
$LANG['rulesengine'][42]="E"; 
$LANG['rulesengine'][43]="Ou"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Asignar : IP do equipo"; 
$LANG['rulesengine'][47]="Asignar : nome do equipo + dominio"; 
$LANG['rulesengine'][48]="Asignar material"; 
$LANG['rulesengine'][49]="Asignar : material polo enderezo MAC"; 
$LANG['rulesengine'][50]="Dicionario modelo de computador"; 
$LANG['rulesengine'][51]="Dicionario tipos de monitores"; 
$LANG['rulesengine'][52]="Dicionario modelos de teléfonos"; 
$LANG['rulesengine'][53]="Dicionario de modelos de periféricos"; 
$LANG['rulesengine'][54]="Dicionario de modelos de impresoras"; 
$LANG['rulesengine'][55]="Dicionario de modelos de electrónica de rede"; 
$LANG['rulesengine'][56]="Modelos"; 
$LANG['rulesengine'][60]="Dicionario tipos de ordenadores"; 
$LANG['rulesengine'][61]="Dicionario tipo de monitor"; 
$LANG['rulesengine'][62]="Dicionario tipos de teléfonos"; 
$LANG['rulesengine'][63]="Dicionario tipos de periféricos"; 
$LANG['rulesengine'][64]="Dicionario de tipos de impresoras"; 
$LANG['rulesengine'][65]="Dicionario de tipos de electrónica de rede"; 
$LANG['rulesengine'][66]="Tipos"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Dicionario de Service Packs"; 
$LANG['rulesengine'][69]="Dicionario de versións"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Retocar dicionario"; 
$LANG['rulesengine'][77]="Dicionarios"; 
$LANG['rulesengine'][78]="Versión"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Dicionario xeral"; 
$LANG['rulesengine'][81]="Resultado da regra"; 
$LANG['rulesengine'][82]="Detalle do resultado"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Probar o motor de regras"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Material tirado ao lixo polo dicionario GLPI"; 
$LANG['rulesengine'][90]="Traballo en progreso..."; 
$LANG['rulesengine'][91]="Traballo rematado."; 
$LANG['rulesengine'][92]="Coidado antes de executar o dicionario"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSIÓN"; 
$LANG['rulesengine'][95]="Escolla un fabricante"; 
$LANG['rulesengine'][96]="Repetir o diccionario para fabricante(s)<br> ( ----- = Todo)"; 
$LANG['rulesengine'][97]="Ningún elemento para comprobar"; 
$LANG['rulesengine'][100]="Información cacheada"; 
$LANG['rulesengine'][102]="Nome da regra"; 
$LANG['rulesengine'][103]="Obxectos na caché"; 
$LANG['rulesengine'][104]="Valor orixinal"; 
$LANG['rulesengine'][105]="Valor modificado"; 
$LANG['rulesengine'][106]="Sen cambios"; 
$LANG['rulesengine'][107]="Inactivo"; 
$LANG['rulesengine'][108]="orixinal"; 
$LANG['rulesengine'][110]="Dereitos de asignación"; 
$LANG['rulesengine'][111]="Entidades de traballo"; 
$LANG['rulesengine'][112]="Dereitos e asignación de entidades"; 
$LANG['rulesengine'][120]="O motor párase cando se verifique unha das regras."; 
$LANG['rulesengine'][121]="O motor executa todas as regras."; 
$LANG['rulesengine'][122]="O motor pasa o resultado dunha regra ás seguintes."; 
$LANG['rulesengine'][130]="Entidade desde LDAP"; 
$LANG['rulesengine'][131]="Entidade desde TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Buscar"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="contén"; 
$LANG['search'][4]="Ordenado por"; 
$LANG['search'][8]="Data inicial"; 
$LANG['search'][9]="Data final"; 
$LANG['search'][10]="en"; 
$LANG['search'][11]="Elementos mostrados"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Non se atoparon elementos"; 
$LANG['search'][16]="Polo menos"; 
$LANG['search'][17]="Engadir un criterio de procura"; 
$LANG['search'][18]="Borrar un criterio de procura"; 
$LANG['search'][19]="Engadir un criterio global de procura"; 
$LANG['search'][20]="Borrar un criterio global de procura"; 

$LANG['setup'][0]="Títulos"; 
$LANG['setup'][2]="Engadir usuario..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Tipos de computadores"; 
$LANG['setup'][5]="Sistemas operativos"; 
$LANG['setup'][6]="Personalización"; 
$LANG['setup'][9]="Interface de rede"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Seguimento privado predeterminado"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Idioma"; 
$LANG['setup'][42]="Tipos de electrónica de rede"; 
$LANG['setup'][43]="Tipos de impresoras"; 
$LANG['setup'][44]="Tipos de monitores"; 
$LANG['setup'][45]="Tipos de caixa"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Seleccione a categoría"; 
$LANG['setup'][63]="Coidado, está a piques de borrar un título usado para un ou máis elementos."; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Tamén pode reemplazar todas as ocorrencias deste título por outro:"; 
$LANG['setup'][67]="Autenticacións externas"; 
$LANG['setup'][69]="Tipos de periféricos"; 
$LANG['setup'][70]="Configuración xeral"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Roseta"; 
$LANG['setup'][74]="Non pode borrar este elemento porque posúe sub-elementos"; 
$LANG['setup'][75]="Debaixo de"; 
$LANG['setup'][79]="Categorías de incidencias"; 
$LANG['setup'][80]="Tipos de terceiro"; 
$LANG['setup'][81]="Asuntos dos documentos"; 
$LANG['setup'][82]="Tipos de contactos"; 
$LANG['setup'][83]="Estado de materiais"; 
$LANG['setup'][84]="Tipos de cartuchos"; 
$LANG['setup'][85]="Tipos de contratos"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Rede"; 
$LANG['setup'][89]="Dominio"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Modelos de computadores"; 
$LANG['setup'][92]="Tipos de consumibles"; 
$LANG['setup'][93]="Interfaces (disco duro, ...)"; 
$LANG['setup'][94]="Modelos de monitores"; 
$LANG['setup'][95]="Modelos de electrónica de rede"; 
$LANG['setup'][96]="Modelos de impresoras"; 
$LANG['setup'][97]="Modelos de periféricos"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Nivel de logging"; 
$LANG['setup'][103]="1- Critical (login error only)"; 
$LANG['setup'][104]="2- Severo (Non utilizado)"; 
$LANG['setup'][105]="3- Important (successful logins)"; 
$LANG['setup'][106]="4- Avisos (Creación, borrado, seguimento)"; 
$LANG['setup'][107]="5- Completo (Todo)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Idioma predeterminado"; 
$LANG['setup'][114]="Cores das prioridades"; 
$LANG['setup'][115]="Limiar de alarma predeterminado para os cartuchos e consumibles"; 
$LANG['setup'][116]="Asignar automaticamente as incidencias ao responsable técnico"; 
$LANG['setup'][117]="Autorizar a consulta anónima das Preguntas Frecuentes"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Inserción automática de usuarios a partir de fontes externas de autenticación"; 
$LANG['setup'][125]="...Desde unha orixe externa"; 
$LANG['setup'][126]="Engadir directamente un usuario dunha fonte externa"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Formato de datas"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Activar o modo OCSNG"; 
$LANG['setup'][134]="Modo OCSNG"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Tradución"; 
$LANG['setup'][137]="Depurar"; 
$LANG['setup'][138]="Utilizar GLPI en modo"; 
$LANG['setup'][139]="Xeneral"; 
$LANG['setup'][140]="Tipos"; 
$LANG['setup'][145]="S.O."; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Intervalo para os horarios"; 
$LANG['setup'][149]="Número de decimais para os importes"; 
$LANG['setup'][150]="Formato de Número"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (para as conexións non anónimas)"; 
$LANG['setup'][156]="Pass (para as conexións non anónimas)"; 
$LANG['setup'][157]="A extensión LDAP do seu intérprete PHP non está instalada"; 
$LANG['setup'][158]="Imposible utilizar LDAP como orixe de conexión externa"; 
$LANG['setup'][159]="Filtro de conexión"; 
$LANG['setup'][162]="Configuración IMAP/POP"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="A extensión IMAP do seu intérprete PHP non está instalada"; 
$LANG['setup'][166]="Imposible utilizar IMAP/POP como orixe de conexión externa"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Opcións de conexión"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Porto (opcional)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="Servidor CAS"; 
$LANG['setup'][175]="Porto"; 
$LANG['setup'][176]="Directorio de base (opcional)"; 
$LANG['setup'][177]="Configuración CAS"; 
$LANG['setup'][178]="A extensión CURL ou DOMXML do seu intérprete PHP non está instalada"; 
$LANG['setup'][179]="Imposible utilizar CAS como orixe de conexión externa"; 
$LANG['setup'][180]="Empregar TLS"; 
$LANG['setup'][181]="Función ldap_start_tls inexistente"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Fuso horario"; 
$LANG['setup'][190]="x509 certificado"; 
$LANG['setup'][191]="correo-e atribuído para x509"; 
$LANG['setup'][192]="Activado"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Gardar estado"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Copiar estado do computador"; 
$LANG['setup'][198]="Configurar estado"; 
$LANG['setup'][199]="Retire o dominio do inicio de sesión na forma login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Mail do administrador"; 
$LANG['setup'][204]="Firma das mensaxes"; 
$LANG['setup'][205]="Mensaxe de proba enviado ao administrador"; 
$LANG['setup'][206]="Fracaso do envío de mensaxe de proba ao administrador"; 
$LANG['setup'][207]="Correo-e de resposta do administrador (se fose necesario)"; 
$LANG['setup'][217]="A función de mail PHP non existe ou está desactivada no seu sistema"; 
$LANG['setup'][218]="É imprescindible utilizar un servidor SMTP"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Límite de horarios para a planificación"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="Técnico anteriormente encargado da incidencia"; 
$LANG['setup'][237]="Administrador"; 
$LANG['setup'][239]="Técnico encargado da incidencia"; 
$LANG['setup'][240]="Opcións de notificación"; 
$LANG['setup'][241]="Non hai criterios persoais. Desexa crear os seus parámetros persoais?"; 
$LANG['setup'][242]="Opcións de alertas"; 
$LANG['setup'][243]="Alertas sobre consumibles"; 
$LANG['setup'][244]="Alertas sobre cartuchos"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Alertas sobre contratos"; 
$LANG['setup'][247]="Alertas sobre datos financeiros"; 
$LANG['setup'][248]="Grupo encargado da incidencia"; 
$LANG['setup'][249]="Grupo solicitante"; 
$LANG['setup'][250]="Vistas predeterminadas"; 
$LANG['setup'][252]="Seleccione os elementos que se amosarán de forma predeterminada"; 
$LANG['setup'][253]="Filtro para procura nos grupos"; 
$LANG['setup'][254]="Tipo de procura"; 
$LANG['setup'][255]="Atributo dos grupos que conteñen os usuarios"; 
$LANG['setup'][256]="Nos usuarios"; 
$LANG['setup'][257]="Nos grupos"; 
$LANG['setup'][258]="Usuarios e grupos"; 
$LANG['setup'][259]="Pertenza a grupos"; 
$LANG['setup'][260]="Atributo do usuario que indica os seus grupos"; 
$LANG['setup'][261]="DN do grupo"; 
$LANG['setup'][262]="Usar DN na procura"; 
$LANG['setup'][263]="Filtro de procura para usuarios"; 
$LANG['setup'][264]="Aviso de expiración de licenzas"; 
$LANG['setup'][271]="Restrinxir a xestión de monitores"; 
$LANG['setup'][272]="Restrinxir a xestión de periféricos"; 
$LANG['setup'][273]="Restrinxir a xestión de teléfonos"; 
$LANG['setup'][274]="para engadir manualmente"; 
$LANG['setup'][275]="Restrinxir a xestión de impresoras"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Copiar"; 
$LANG['setup'][284]="Limpar"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Comprobar si hai unha nova versión dispoñible"; 
$LANG['setup'][301]="Hai dispoñible unha nova versión:"; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="Ten instalada a última versión dispoñible"; 
$LANG['setup'][304]="Verificación imposible. Si está detrás dun proxy, configúreo."; 
$LANG['setup'][305]="Todos os días"; 
$LANG['setup'][306]="Comprobar a presenza de actualizaciones"; 
$LANG['setup'][307]="Nunca"; 
$LANG['setup'][308]="Todas as semanas"; 
$LANG['setup'][309]="Todos os meses"; 
$LANG['setup'][310]="Imposible conectar co sitio."; 
$LANG['setup'][311]="Imposible conectarse ao servidor proxy"; 
$LANG['setup'][312]="Non hai datos dispoñibles neste sitio web"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Relación cos materiais para a apertura de incidencias"; 
$LANG['setup'][351]="Todos os materiais"; 
$LANG['setup'][352]="Materiais asociables cunha incidencia"; 
$LANG['setup'][360]="Campos automáticos (marcados con *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Asunto predeterminado dos documentos relacionados coas incidencias"; 
$LANG['setup'][503]="Modelos de teléfonos"; 
$LANG['setup'][504]="Tipos de teléfonos"; 
$LANG['setup'][505]="Tipos de alimentación de teléfono"; 
$LANG['setup'][601]="Valor LDAP"; 
$LANG['setup'][602]="Conexión á base de datos OCSNG"; 
$LANG['setup'][603]="Engadir un usuario"; 
$LANG['setup'][604]="Asociar a un grupo"; 
$LANG['setup'][606]="Non se pode engadir. Este usuario xa existe."; 
$LANG['setup'][607]="Asociar a un perfil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Título de incidencia obrigatorio"; 
$LANG['setup'][611]="O contido da incidencia é obrigatorio"; 
$LANG['setup'][612]="A categoría da incidencia é obrigatoria"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Ligazón"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Xeral"; 
$LANG['setup'][704]="Notificacións"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Replicar Mysql"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Base de datos"; 
$LANG['setup'][803]="Diferencia entre maestro e esclavo"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Base de datos escrava desincronizada!"; 
$LANG['setup'][809]="Réplica MySQL : só lectura"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Versión comprada"; 
$LANG['software'][2]="Versión en uso"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Ilimitado"; 
$LANG['software'][5]="Versións"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Engadir versión"; 
$LANG['software'][8]="Engadir unha licenza"; 
$LANG['software'][11]="Licenzas"; 
$LANG['software'][17]="software instalado"; 
$LANG['software'][19]="Instalacións"; 
$LANG['software'][20]="Restante"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Actualización"; 
$LANG['software'][30]="Tipo de licenzas"; 
$LANG['software'][32]="Expiración"; 
$LANG['software'][44]="Instalación dun software"; 
$LANG['software'][45]="Desinstalación dun software"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Agrupación"; 
$LANG['software'][48]="Reagrupar"; 
$LANG['software'][49]="Programas enviados ao lixo despois de reagrupar"; 
$LANG['software'][50]="Asignado ao computador"; 
$LANG['software'][51]="O número debe ser 1 para que teña efecto"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Categoría de software"; 

$LANG['state'][0]="Estado"; 
$LANG['state'][6]="Tipo de material"; 
$LANG['state'][7]="Non se atoparon   materiais"; 
$LANG['state'][11]="Resumo"; 

$LANG['stats'][0]="Seleccione as estatísticas que desexa ver"; 
$LANG['stats'][1]="Globais"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Por títulos"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Demora media do tratamento de incidencias"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Incidencias pechadas"; 
$LANG['stats'][13]="Incidencias asignadas"; 
$LANG['stats'][15]="Duración media do tratamento de incidencias"; 
$LANG['stats'][16]="Nome do técnico"; 
$LANG['stats'][20]="Nome de usuario"; 
$LANG['stats'][23]="Non hai estatísticas dispoñibles"; 
$LANG['stats'][25]="Duración real media de tratamento do servizo"; 
$LANG['stats'][27]="Duración real total de servizos"; 
$LANG['stats'][30]="Demora media de atención de servizo"; 
$LANG['stats'][31]="Días"; 
$LANG['stats'][33]="Mins"; 
$LANG['stats'][34]="Segs"; 
$LANG['stats'][35]="Servizos"; 
$LANG['stats'][44]="Nome do provedor"; 
$LANG['stats'][45]="Por material"; 
$LANG['stats'][47]="Por incidencias"; 
$LANG['stats'][48]="(asignado)"; 
$LANG['stats'][49]="(seguimento)"; 

$LANG['title'][5]="Base de coñecemento"; 
$LANG['title'][6]="Electrónica de rede"; 
$LANG['title'][9]="Estados de materiais"; 
$LANG['title'][10]="Seguimento de incidencias"; 
$LANG['title'][13]="Información do usuario"; 
$LANG['title'][14]="Fontes de autenticación externas"; 
$LANG['title'][24]="Soporte"; 
$LANG['title'][26]="Principal"; 
$LANG['title'][27]="Conexións"; 
$LANG['title'][28]="Incidencias"; 
$LANG['title'][30]="Compoñentes"; 
$LANG['title'][33]="Ligazóns externas"; 
$LANG['title'][34]="Ligazón"; 
$LANG['title'][37]="Notas"; 
$LANG['title'][38]="Histórico"; 
$LANG['title'][40]="Notas persoais e públicas"; 
$LANG['title'][42]="Modificación masiva"; 
$LANG['title'][43]="Rexistro do sistema"; 

$LANG['tracking'][1]="Os meus materiais"; 
$LANG['tracking'][2]="Ou procura completa"; 
$LANG['tracking'][3]="Datos inválidos. Actualización cancelada"; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Sen descrición. Por favor, comece de novo"; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Documento de Incidencia"; 
$LANG['tracking'][29]="Cantidade"; 
$LANG['tracking'][30]="Novas"; 
$LANG['tracking'][31]="En curso (asignadas)"; 
$LANG['tracking'][32]="En curso (planificadas)"; 
$LANG['tracking'][34]="Directa"; 
$LANG['tracking'][35]="Escrita"; 
$LANG['tracking'][37]="Conservar as incidencias ao purgar un elemento do inventario"; 
$LANG['tracking'][38]="Correo de seguimento enviado a"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Transferencia"; 
$LANG['transfer'][3]="Si xa non se usa"; 
$LANG['transfer'][4]="Baleirar a lista de elementos a transferir"; 
$LANG['transfer'][5]="Pode engadir máis elementos ou transferir os que hai agora"; 
$LANG['transfer'][6]="Recoméndase facer unha copia de seguridade antes de transferir elementos."; 
$LANG['transfer'][7]="Elementos a transferir"; 
$LANG['transfer'][8]="Modo de transferencia"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Erro durante a actualización da base de datos"; 
$LANG['update'][91]="Coidado!"; 
$LANG['update'][92]="Vai a actualizar a base de datos GLPI que se chama  :"; 
$LANG['update'][93]="A conexión coa base de datos foi correcta"; 
$LANG['update'][94]="A actualización foi correcta, a súa base de datos está actualizada"; 
$LANG['update'][95]="A conexión á base de datos fallou, comprobe os parámetros de conexión que figuran no ficheiro config_db.php"; 
$LANG['update'][96]="Todos os administradores teñen permisos de 'super-admin'.Taméneste novo tipo de usuario."; 
$LANG['update'][105]="Imposible acceder á actualización desta forma!"; 
$LANG['update'][106]="Volver a GLPI"; 
$LANG['update'][107]="Agora debe proceder á actualización do contido anterior da súa base de datos"; 
$LANG['update'][130]="Actualización de lugares"; 
$LANG['update'][131]="A nova estrutura é jerárquica"; 
$LANG['update'][132]="Si utiliza un carácter de separación pode indicalo para automatizar a xeración da xerarquía"; 
$LANG['update'][133]="Pode tamén especificar un lugar de base que incluirá todos os lugares xerados."; 
$LANG['update'][134]="Carácter de separación"; 
$LANG['update'][135]="Lugar raíz"; 
$LANG['update'][136]="Velaquí a nova xerarquía xerada. Si é correcta pode aceptala."; 
$LANG['update'][137]="Nova xerarquía"; 
$LANG['update'][138]="Lugares actuais"; 
$LANG['update'][139]="Optimización das táboas"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Título"; 
$LANG['users'][2]="Categoría"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>